@@ -18,7 +18,7 @@ __all__ = [
 class Bitpin:
     def __init__(self, api_key: t.Optional[str] = None, api_secret: t.Optional[str] = None,
                  requests_params: t.Optional[t.Dict] = None,
-                 logger: t.Optional[t.Union[Logger, t.Type[Logger]]] = Logger()):
+                 logger: t.Optional[t.Union[Logger, t.Type[Logger]]] = Logger('Bitpin')):
         """
         Initialize the Bitpin SDK .
 
